summaryrefslogtreecommitdiffstats
path: root/third_party/libpng/png.h
diff options
context:
space:
mode:
Diffstat (limited to 'third_party/libpng/png.h')
-rw-r--r--third_party/libpng/png.h23
1 files changed, 13 insertions, 10 deletions
diff --git a/third_party/libpng/png.h b/third_party/libpng/png.h
index 267677a..8092989 100644
--- a/third_party/libpng/png.h
+++ b/third_party/libpng/png.h
@@ -1,6 +1,6 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.2.36 - May 7, 2009
* Copyright (c) 1998-2009 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -8,7 +8,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.2.36 - May 7, 2009: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -226,6 +226,9 @@
* 1.2.36rc01 13 10236 12.so.0.36[.0]
* 1.0.44 10 10044 10.so.0.44[.0]
* 1.2.36 13 10236 12.so.0.36[.0]
+ * 1.2.37beta01-03 13 10237 12.so.0.37[.0]
+ * 1.2.37rc01 13 10237 12.so.0.37[.0]
+ * 1.2.37 13 10237 12.so.0.37[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -255,7 +258,7 @@
* If you modify libpng you may insert additional notices immediately following
* this sentence.
*
* libpng versions 1.2.6, August 15, 2004, through 1.2.36, May 7, 2009, are
* Copyright (c) 2004, 2006-2009 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -367,13 +370,13 @@
* Y2K compliance in libpng:
* =========================
*
- * May 7, 2009
+ * June 4, 2009
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.2.36 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -429,9 +432,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.2.36"
+#define PNG_LIBPNG_VER_STRING "1.2.37"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.2.36 - May 7, 2009\n"
+ " libpng version 1.2.37 - June 4, 2009\n"
#define PNG_LIBPNG_VER_SONUM 0
#define PNG_LIBPNG_VER_DLLNUM 13
@@ -439,7 +442,7 @@
/* These should match the first 3 components of PNG_LIBPNG_VER_STRING: */
#define PNG_LIBPNG_VER_MAJOR 1
#define PNG_LIBPNG_VER_MINOR 2
-#define PNG_LIBPNG_VER_RELEASE 36
+#define PNG_LIBPNG_VER_RELEASE 37
/* This should match the numeric part of the final component of
* PNG_LIBPNG_VER_STRING, omitting any leading zero: */
@@ -467,7 +470,7 @@
* Versions 0.7 through 1.0.0 were in the range 0 to 100 here (only
* version 1.0.0 was mis-numbered 100 instead of 10000). From
* version 1.0.1 it's xxyyzz, where x=major, y=minor, z=release */
-#define PNG_LIBPNG_VER 10236 /* 1.2.36 */
+#define PNG_LIBPNG_VER 10237 /* 1.2.37 */
#ifndef PNG_VERSION_INFO_ONLY
/* include the compression library's header */
@@ -1491,7 +1494,7 @@ struct png_struct_def
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef png_structp version_1_2_36;
+typedef png_structp version_1_2_37;
typedef png_struct FAR * FAR * png_structpp;
@@ -1,6 +1,6 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.2.36 - May 7, 2009
+ * libpng version 1.2.37 - June 4, 2009
* Copyright (c) 1998-2009 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -8,7 +8,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.2.36 - May 7, 2009: Glenn
+ * libpng versions 0.97, January 1998, through 1.2.37 - June 4, 2009: Glenn
* See also "Contributing Authors", below.
*
@@ -255,7 +258,7 @@
* this sentence.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.2.36, May 7, 2009, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.2.37, June 4, 2009, are
* Copyright (c) 2004, 2006-2009 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -367,13 +370,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.2.36 are Y2K compliant. It is my belief that earlier
+ * upward through 1.2.37 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*